# __main__.py

import sys
import converts

def main():
    c2f = converts.c2f()
    f2c = converts.f2c()
    add_temp = converts.add_temp()
    
if __name__ == "__main__":
    main()